From 13e8d3d10d773a07c5586c6f8efc4c526b5db1d0 Mon Sep 17 00:00:00 2001
From: Thomas Munro <thomas.munro@gmail.com>
Date: Fri, 24 Mar 2023 10:47:36 +1300
Subject: [PATCH] Fix missing WAIT_EVENT_SLRU_FLUSH_SYNC reporting.

Commit dee663f7 moved fsync() calls for SLRU files into the
checkpointer, but accidentally stopped reporting
WAIT_EVENT_SLRU_FLUSH_SYNC as the wait event while in the system call.
Fix, so that SlruSyncFileTag() mirrors the way the equivalent wait event
for data files is reported by mdsyncfiletag().

Back-patch to 14, where dee663f7 landed.

Reported-by: Bharath Rupireddy <bharath.rupireddyforpostgres@gmail.com>
Discussion: https://postgr.es/m/CALj2ACVY3eA261mUDO8xcMJGDwj_OHpaxEUMc5L9jxkj3fvcpg%40mail.gmail.com
---
 src/backend/access/transam/slru.c | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/src/backend/access/transam/slru.c b/src/backend/access/transam/slru.c
index 5ab86238a9..2a42f31ec2 100644
--- a/src/backend/access/transam/slru.c
+++ b/src/backend/access/transam/slru.c
@@ -1603,7 +1603,9 @@ SlruSyncFileTag(SlruCtl ctl, const FileTag *ftag, char *path)
 	if (fd < 0)
 		return -1;
 
+	pgstat_report_wait_start(WAIT_EVENT_SLRU_FLUSH_SYNC);
 	result = pg_fsync(fd);
+	pgstat_report_wait_end();
 	save_errno = errno;
 
 	CloseTransientFile(fd);
-- 
2.39.2

